/***********************************************************************/
/* Open Visualization Data Explorer                                    */
/* (C) Copyright IBM Corp. 1989,1999                                   */
/* ALL RIGHTS RESERVED                                                 */
/* This code licensed under the                                        */
/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
/***********************************************************************/
#define ARRWPTS 6 
#define ARRWLNS 5 
static Point points[ARRWPTS] = {
 {  0.0000000000F,      0.0000000000F,      0.0000000000F }, 
 {  0.0000000000F,      1.0000000000F,      0.0000000000F }, 
 { -0.2500000000F,      0.8000000000F,     -0.2500000000F }, 
 { -0.2500000000F,      0.8000000000F,      0.2500000000F }, 
 {  0.2500000000F,      0.8000000000F,     -0.2500000000F }, 
 {  0.2500000000F,      0.8000000000F,      0.2500000000F }, 
};

#include <dxconfig.h>

   
static Line lines[] = {
  {  0,       1 },       
  {  2,       1 },      
  {  3,       1 },      
  {  4,       1 },      
  {  5,       1 }     
};
